quantizationtools.QTarget
=========================

.. abjad-lineage:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget

.. autoclass:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.beats
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.item_klass
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.items
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTarget.QTarget.QTarget.__repr__
   :noindex:
